<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'SPIPの掲示板（プライベートと公開）',
	'forum_slogan' => 'SPIPの掲示板（プライベートと公開）の管理',
];
